
# Changelog



## [0.0.1](https://github.com/x55xaa/arduck/releases/tag/v0.0.1) - 2025-05-20

_🌱 Initial release._

### Added

- Add supported keyboard layouts and special keys ([d268d72](https://github.com/x55xaa/arduck/commit/d268d722fdea1ce42b5739f5a62c00ef2d90b9a7)) - (Stefano Cuizza)
- Add a CLI ([5c6af0c](https://github.com/x55xaa/arduck/commit/5c6af0c540929977aa695e4ab646415cb1a0843e)) - (Stefano Cuizza)
- Add templates ([9c3aabf](https://github.com/x55xaa/arduck/commit/9c3aabf5d8f5670315d617321245feab78b67364)) - (Stefano Cuizza)
- Add default template ([1211b14](https://github.com/x55xaa/arduck/commit/1211b149f1ddf6157936b0b004c74ddee959279c)) - (Stefano Cuizza)
- Add ability to specify template through the CLI ([d8f8fa4](https://github.com/x55xaa/arduck/commit/d8f8fa42e5a12adddbf42e8047cf92b78d7b959b)) - (Stefano Cuizza)
- Add ability to repeat injection in a loop ([7e2cf36](https://github.com/x55xaa/arduck/commit/7e2cf3615eaaccc197428efcb7bf0a2a7ad37dda)) - (Stefano Cuizza)

### Changed

- Flatten one character combos ([b94e5db](https://github.com/x55xaa/arduck/commit/b94e5db63c23496bfc182819d494c3bc0b4bec57)) - (Stefano Cuizza)
- Merge consecutive delays ([fa1c365](https://github.com/x55xaa/arduck/commit/fa1c3658e01f07018efaf4e6dcb397ce0ecdec8f)) - (Stefano Cuizza)

### Fixed

- Tokenizer now translates special keys correctly ([f1c92e0](https://github.com/x55xaa/arduck/commit/f1c92e0f8839cedce491a92bb3dde299466d7c83)) - (Stefano Cuizza)
- Add shift correction to counter index mismatch ([f768fb4](https://github.com/x55xaa/arduck/commit/f768fb4f49cf8085ea5b6bad49084e7125356778)) - (Stefano Cuizza)
- Change default outfile to `sketch.ino` ([7089673](https://github.com/x55xaa/arduck/commit/708967396441d495e30dc1d280230a855db7c473)) - (Stefano Cuizza)
- The `any.default` template can now handle delays that appear right before the end of the injection ([674144e](https://github.com/x55xaa/arduck/commit/674144e32b2f3386ac57fd2d0471368dc23362e1)) - (Stefano Cuizza)

